==> pegasus-merchandise-service-1.1.3-sources.jar: com/thebeastshop/pegasus/merchandise/domain/PcsWatermarkDomain.java <==
package com.thebeastshop.pegasus.merchandise.domain;

import com.thebeastshop.pegasus.merchandise.cond.PcsWatermarkCond;
import com.thebeastshop.pegasus.merchandise.model.PcsSkuWatermark;
import com.thebeastshop.pegasus.merchandise.model.ProdWatermark;
import com.thebeastshop.pegasus.merchandise.vo.PcsWatermarkVO;
import com.thebeastshop.pegasus.merchandise.vo.ProdSkuVO;
import com.thebeastshop.pegasus.merchandise.vo.ProductWatermarkVO;

import javax.management.OperationsException;

import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * @author gongjun
 * @since 2016-08-30
 */
public interface PcsWatermarkDomain {

    int addIcon(PcsWatermarkVO watermarkVO);

    int updateIcon(PcsWatermarkVO watermarkVO);

    int updateSkuWatrmarkByCodeList(String skuCode, List<String> codeList);

    int updateProdWatrmarkByCodeList(ProdSkuVO prod, List<String> watermarkCodeList, boolean isEmptyBeforeUpdate);

    int saveOrUpdateSkuWatermark(PcsSkuWatermark skuWatermark);

    PcsWatermarkVO findWatermarkById(Long id);

    List<PcsWatermarkVO> queryWatermarkList(Map<String, Object> params);

    List<ProdSkuVO> queryProdWatermarkList(PcsWatermarkCond cond);

    List<ProdSkuVO> querySkuListByProd(Long prodId);

    List<ProdSkuVO> queryProdListBySkuCode(String code);

    int deleteProdWatermarkByIds(List<String> idList);

    int saveOrUpdateProdWatermark(ProdWatermark prodWatermark) throws OperationsException;

    List<ProdSkuVO> queryProdWatermarkListByParams(List<String> params);

    ProdSkuVO queryProductByProdId(Long prodId);

    /**
     * 通过 productcodes 查询  可以使用的水印 标签
     * @author lijing
     * @time 2016-09-10 20:11
     * @param productCodes
     * @return
     */
    Map<String,ProductWatermarkVO> seleckWatermarkByProductCodes(List<String> productCodes);
    
    int setProdWatermarkValidityByIds(Map<String, Object> params);
    
    int checkProdWatermarkHasValid(String watermarkCode,String skuCode);


}

==> pegasus-merchandise-service-1.3.0-sources.jar: com/thebeastshop/pegasus/merchandise/domain/PcsWatermarkDomain.java <==
package com.thebeastshop.pegasus.merchandise.domain;

import com.thebeastshop.pegasus.merchandise.cond.PcsWatermarkCond;
import com.thebeastshop.pegasus.merchandise.model.PcsSkuWatermark;
import com.thebeastshop.pegasus.merchandise.model.ProdWatermark;
import com.thebeastshop.pegasus.merchandise.vo.PcsWatermarkVO;
import com.thebeastshop.pegasus.merchandise.vo.ProdSkuVO;
import com.thebeastshop.pegasus.merchandise.vo.ProductWatermarkVO;

import javax.management.OperationsException;
import java.util.List;
import java.util.Map;

/**
 * @author gongjun
 * @since 2016-08-30
 */
public interface PcsWatermarkDomain {

    int addIcon(PcsWatermarkVO watermarkVO);

    int updateIcon(PcsWatermarkVO watermarkVO);

    int updateSkuWatrmarkByCodeList(String skuCode, List<String> codeList);

    int updateProdWatrmarkByCodeList(ProdSkuVO prod, List<String> watermarkCodeList, boolean isEmptyBeforeUpdate);

    int saveOrUpdateSkuWatermark(PcsSkuWatermark skuWatermark);

    PcsWatermarkVO findWatermarkById(Long id);

    List<PcsWatermarkVO> queryWatermarkList(Map<String, Object> params);

    List<ProdSkuVO> queryProdWatermarkList(PcsWatermarkCond cond);

    List<ProdSkuVO> querySkuListByProd(Long prodId);

    List<ProdSkuVO> queryProdListBySkuCode(String code);

    int deleteProdWatermarkByIds(List<String> idList);

    int saveOrUpdateProdWatermark(ProdWatermark prodWatermark) throws OperationsException;

    List<ProdSkuVO> queryProdWatermarkListByParams(List<String> params);

    ProdSkuVO queryProductByProdId(Long prodId);

    /**
     * 通过 productcodes 查询  可以使用的水印 标签
     * @author lijing
     * @time 2016-09-10 20:11
     * @param productCodes
     * @return
     */
    Map<String,ProductWatermarkVO> seleckWatermarkByProductCodes(List<String> productCodes);
    
    int setProdWatermarkValidityByIds(Map<String, Object> params);
    
    int checkProdWatermarkHasValid(String watermarkCode,String skuCode);

    int updateActiveTrueWatermark();
    int updateActiveFalseWatermark();


}
